@@ -34,7 +34,7 @@ import eds
 from configuration import conf, runtime, dialogs
 
 import stuff
-from KeyBinder import *
+import keybinder
 from hamsterdbus import HAMSTER_URI, HamsterDbusController
 
 # controllers for other windows
@@ -110,10 +110,6 @@ class PanelButton(gtk.ToggleButton):
         self.label.set_markup("") #clear - seems to fix the warning
         self.label.set_markup(label)
 
-    def get_pos(self):
-        return gtk.gdk.Window.get_origin(self.label.window)
-
-
     def use_two_line_format(self):
         if not self.get_parent():
             return False
@@ -202,6 +198,9 @@ class HamsterApplet(object):
         # load window of activity switcher and todays view
         self._gui = stuff.load_ui_file("applet.ui")
         self.window = self._gui.get_object('hamster-window')
+        # on close don't destroy the popup, just hide it instead
+        self.window.connect("delete_event", lambda *args: self.__show_toggle(None, False))
+        self.window.connect("window-state-event", self.on_window_state_changed)
 
         self.new_name = widgets.ActivityEntry()
         self.new_name.connect("value-entered", self.on_switch_activity_clicked)
@@ -243,6 +242,9 @@ class HamsterApplet(object):
         self.notify_interval = conf.get("notify_interval")
         self.workspace_tracking = conf.get("workspace_tracking")
 
+        self.hotkey = conf.get("keybinding")
+        self.bind_hotkey()
+
         runtime.dispatcher.add_handler('conf_changed', self.on_conf_changed)
 
         # Load today's data, activities and set label
@@ -259,7 +261,6 @@ class HamsterApplet(object):
         runtime.dispatcher.add_handler('panel_visible', self.__show_toggle)
         runtime.dispatcher.add_handler('activity_updated', self.after_activity_update)
         runtime.dispatcher.add_handler('day_updated', self.after_fact_update)
-        runtime.dispatcher.add_handler('keybinding_activated', self.on_keybinding_activated)
 
         self.screen = None
         if self.workspace_tracking:
@@ -276,6 +277,14 @@ class HamsterApplet(object):
         self.prev_size = None
 
 
+    def bind_hotkey(self):
+        try:
+            print 'Binding shortcut %s to popup hamster' % self.hotkey
+            keybinder.bind(self.hotkey, self.on_keybinding_activated)
+        except KeyError:
+            pass # don't care
+
+
     def init_workspace_tracking(self):
         if not wnck: # can't track if we don't have the trackable
             return
@@ -324,7 +333,7 @@ class HamsterApplet(object):
             duration = delta.seconds /  60
 
             if duration and duration % self.notify_interval == 0:
-                message = _(u"Working on <b>%s</b>") % self.last_activity['name']
+                message = self.last_activity['name']
 
         elif self.notify_on_idle:
             #if we have no last activity, let's just calculate duration from 00:00
@@ -337,13 +346,6 @@ class HamsterApplet(object):
             self.notification.show()
 
 
-    def edit_cb(self, n, action):
-        dialogs.edit.show(self.applet, activity_id = self.last_activity['id'])
-
-    def switch_cb(self, n, action):
-        self.__show_toggle(None, not self.button.get_active())
-
-
     def load_day(self):
         """sets up today's tree and fills it with records
            returns information about last activity"""
@@ -408,19 +410,18 @@ class HamsterApplet(object):
             delta = dt.datetime.now() - activity['start_time']
             duration = delta.seconds /  60
 
-            self._gui.get_object("more_info_button").hide()
-            self.get_widget("last_activity_duration").show()
-            self.get_widget("last_activity_description").show()
-            self.get_widget("last_activity_category").show()
-
-            self.get_widget("last_activity_duration").set_text(stuff.format_duration(duration) or _("Just started"))
-
             self.get_widget("last_activity_name").set_text(activity['name'])
             if activity['category'] != _("Unsorted"):
                 self.get_widget("last_activity_category") \
                     .set_text(" - %s" % activity['category'])
+            self.get_widget("last_activity_category").show()
 
+
+            self._gui.get_object("more_info_button").hide()
+
+            self.get_widget("last_activity_duration").set_text(stuff.format_duration(duration) or _("Just started"))
             self.get_widget("last_activity_description").set_text(activity['description'] or "")
+            self.get_widget("activity_info_box").show()
 
             self.tag_box.draw(activity["tags"])
         else:
@@ -428,13 +429,12 @@ class HamsterApplet(object):
             self.get_widget("start_tracking").show()
 
             self.get_widget("last_activity_name").set_text(_("No activity"))
+            self.get_widget("last_activity_category").hide()
 
-            self.get_widget("last_activity_duration").hide()
+            self.get_widget("activity_info_box").hide()
             self._gui.get_object("more_info_button").show()
 
-            self.get_widget("last_activity_category").hide()
             self.tag_box.draw([])
-            self.get_widget("last_activity_description").hide()
 
 
     def delete_selected(self):
@@ -458,7 +458,7 @@ class HamsterApplet(object):
 
         if not is_active:
             self.window.hide()
-            return
+            return True
 
         self.load_day() # reload day each time before showing to avoid outdated last activity
         self.update_label() #update also label, otherwise we can get 1 minute difference in durations (due to timers refreshed once a minute)
@@ -467,7 +467,7 @@ class HamsterApplet(object):
 
 
         # doing unstick / stick here, because sometimes while switching
-        # between workplaces window still manages to dissappear
+        # between workplaces window still manages to disappear
         self.window.unstick()
         self.window.stick() #show on all desktops
 
@@ -477,31 +477,51 @@ class HamsterApplet(object):
 
 
     def position_popup(self):
-        label_geom = self.button.get_allocation()
-        window_geom = self.window.get_allocation()
+        label = self.button.get_allocation()
+        window = self.window.get_allocation()
 
-        x, y = self.button.get_pos()
+        x, y = self.button.get_parent_window().get_origin()
 
         self.popup_dir = self.applet.get_orient()
-        if self.popup_dir == gnomeapplet.ORIENT_DOWN:
-            y = y + label_geom.height
-        elif self.popup_dir == gnomeapplet.ORIENT_UP:
-            y = y - window_geom.height
-        elif self.popup_dir == gnomeapplet.ORIENT_RIGHT:
-            x = x + label_geom.width
-        elif self.popup_dir == gnomeapplet.ORIENT_LEFT:
-            x = x - window_geom.width
+
+        if self.popup_dir in (gnomeapplet.ORIENT_DOWN, gnomeapplet.ORIENT_UP):
+            if self.popup_dir == gnomeapplet.ORIENT_DOWN:
+                y = y + label.height
+            else:
+                y = y - window.height
+
+            screen_w = self.button.get_screen().get_width()
+            if x + window.width > screen_w:
+                x = screen_w - window.width
+
+        elif self.popup_dir in (gnomeapplet.ORIENT_RIGHT, gnomeapplet.ORIENT_LEFT):
+            if self.popup_dir == gnomeapplet.ORIENT_RIGHT:
+                x = x + label.width
+            else:
+                x = x - window.width
+
+            screen_h = self.button.get_screen().get_height()
+            if y + window.height > screen_h:
+                y = screen_h - window.height
 
         self.window.move(x, y)
 
     def _delayed_display(self):
         """show window only when gtk has become idle. otherwise we get
         mixed results. TODO - this looks like a hack though"""
+        self.window.show()
         self.window.present()
         self.new_name.grab_focus()
 
 
     """events"""
+    def on_window_state_changed(self, window, event):
+        """untoggle the button when window gets minimized"""
+        if (event.changed_mask & gtk.gdk.WINDOW_STATE_ICONIFIED \
+            and event.new_window_state & gtk.gdk.WINDOW_STATE_ICONIFIED):
+            self.button.set_active(False)
+
+
     def on_toggle(self, widget):
         self.__show_toggle(None, self.button.get_active())
 
@@ -656,7 +676,7 @@ class HamsterApplet(object):
             self.notification.show()
 
     """global shortcuts"""
-    def on_keybinding_activated(self, event, data):
+    def on_keybinding_activated(self):
         self.__show_toggle(None, not self.button.get_active())
 
 
@@ -680,6 +700,15 @@ class HamsterApplet(object):
                 if self.screen:
                     self.screen.disconnect(self.screen.workspace_handler)
                     self.screen = None
+        elif key == "keybinding":
+            try:
+                keybinder.unbind(self.hotkey)
+            except KeyError:
+                pass # don't care
+
+            self.hotkey = value
+            self.bind_hotkey()
+
 
 
     def on_activity_text_changed(self, widget):
