@@ -58,6 +58,7 @@ class TagsEntry(gtk.Entry):
         self.connect("key-release-event", self._on_key_release_event)
         self.connect("focus-out-event", self._on_focus_out_event)
         self.connect("parent-set", self._on_parent_set)
+        self._parent_click_watcher = None # bit lame but works
 
         runtime.dispatcher.add_handler('new_tags_added', self.refresh_tags)
         self.show()
@@ -71,14 +72,23 @@ class TagsEntry(gtk.Entry):
         return [tag.strip() for tag in self.get_text().decode('utf8', 'replace').split(",") if tag.strip()]
 
     def on_tag_selected(self, tag_box, tag):
-        tags = self.get_tags()
-        tags.append(tag)
+        cursor_tag = self.get_cursor_tag()
+        if cursor_tag and tag.startswith(cursor_tag):
+            self.replace_tag(cursor_tag, tag)
+            tags = self.get_tags()
+        else:
+            tags = self.get_tags()
+            tags.append(tag)
 
         self.tag_box.selected_tags = tags
 
-        self.set_text(", ".join(tags))
+
+        self.set_text("%s, " % ", ".join(tags))
         self.set_position(len(self.get_text()))
 
+        self.populate_suggestions()
+        self.show_popup()
+
     def on_tag_unselected(self, tag_box, tag):
         tags = self.get_tags()
         while tag in tags: #it could be that dear user is mocking us and entering same tag over and over again
@@ -86,18 +96,24 @@ class TagsEntry(gtk.Entry):
 
         self.tag_box.selected_tags = tags
 
-        self.set_text(", ".join(tags))
+        self.set_text("%s, " % ", ".join(tags))
         self.set_position(len(self.get_text()))
 
 
     def hide_popup(self):
         self.popup.hide()
+        if self._parent_click_watcher and self.get_toplevel().handler_is_connected(self._parent_click_watcher):
+            self.get_toplevel().disconnect(self._parent_click_watcher)
+            self._parent_click_watcher = None
 
     def show_popup(self):
         if not self.filter_tags:
             self.popup.hide()
             return
 
+        if not self._parent_click_watcher:
+            self._parent_click_watcher = self.get_toplevel().connect("button-press-event", self._on_focus_out_event)
+
         alloc = self.get_allocation()
         x, y = self.get_parent_window().get_origin()
 
@@ -190,7 +206,7 @@ class TagsEntry(gtk.Entry):
             cursor = self.get_position()
 
         self.set_text(", ".join(tags))
-        self.set_position(cursor + len(new_tag)-len(old_tag)) # put the cursor back
+        self.set_position(len(self.get_text()))
 
     def _on_key_press_event(self, entry, event):
         if event.keyval == gtk.keysyms.Tab:
@@ -240,6 +256,9 @@ class TagBox(graphics.Area):
         self.redraw_canvas()
 
     def on_tag_click(self, widget, regions):
+        if not regions:
+            return
+
         tag = regions[0]
         if tag in self.selected_tags:
             #self.selected_tags.remove(tag)
